# -*- coding:utf-8 -*-
# @author :adolf
import requests
import json
import base64
import cv2

# file_path = '/home/shizai/adolf/data/jindie/ehtd.png'
file_path = 'test_imgs/2BPX.png'
# img = cv2.imread(file_path)
# print(img.shape)

url = "https://rpa-vc-verify.ai-indeed.com/verification_service/"
# url = "http://192.168.0.13:5000/ocr_service/"


def get_result(encodestr):
    payload = {"image": encodestr, "scenes": 'dazongguan'}
    r = requests.post(url, json=payload)
    # print(r.text)
    res = json.loads(r.text)
    return res


with open(file_path, 'rb') as f:
    image = f.read()
    encodestr = str(base64.b64encode(image), 'utf-8')

res_ = get_result(encodestr)
print(res_)



# -*- coding:utf-8 -*-
# @author :adolf
import cv2
import torch.utils.data as data
import torch
import torchvision.transforms as transforms
import random
import os
from tqdm import tqdm


class RawDataset(data.Dataset):
    def __init__(self, file_path, imgH, alphabet_dict, verification_length, is_training):
        # for png_name in data_list:
        #     img = cv2.imread(file_path + png_name)
        #     assert img.shape[2] == 3, "请读入3通道图片"
        #     img = cv2.resize(img, (imgW, imgH))
        #     img = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
        #     label = png_name.split('.')[0]
        #     all_data_list.append((img, label))
        # self.img_input = all_data_list
        self.root = file_path
        self.imgH = imgH
        self.imgW = None
        self.is_training = is_training

        self.patients = list(sorted(os.listdir(self.root)))
        validation_cases = int(0.1 * len(self.patients))

        validation_patients = random.sample(self.patients, k=validation_cases)
        # validation_patients = ['img_363.jpg']

        if not is_training:
            self.patients = validation_patients
        else:
            self.patients = sorted(
                list(set(self.patients).difference(validation_patients))
            )
        self.img_input = list()

        for img_name in tqdm(self.patients):
            try:
                img_path = os.path.join(self.root, img_name)
                img = cv2.imread(img_path)
                self.imgW = int(img.shape[1] * self.imgH / img.shape[0])
                assert img.shape[2] == 3, "请读入3通道图片"
                img = cv2.resize(img, (self.imgW, self.imgH))
                img = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
                label = img_name.split('.')[0][:verification_length]
                self.img_input.append((img, label))
            except Exception as e:
                print(img_name)
                print(e)
                continue

        self.alphabet_dict = alphabet_dict
        self.transform = transforms.Compose([transforms.ToTensor()])
        self.target_transform = self.converter_text_to_label

    def __len__(self):
        return len(self.img_input)

    def __getitem__(self, index):
        img, label = self.img_input[index]
        img = self.transform(img)
        label, length = self.target_transform(label)
        return img, label, length

    def converter_text_to_label(self, label_str):
        # print(label_str)
        # print(self.alphabet_dict)
        try:
            label = [self.alphabet_dict[char] for char in label_str]
        except Exception as e:
            print(e)
            label_str = label_str.replace(' ', '')
            label = [self.alphabet_dict[char] for char in label_str]
        length = [len(label)]
        return torch.IntTensor(label), torch.IntTensor(length)



# -*- coding:utf-8 -*-
# @author :adolf
import os
import json
from flask import Flask
from flask import request
from werkzeug.utils import secure_filename
import traceback
import sys
from flask_cors import CORS

"""
只要用于服务器的文件上传
"""
app = Flask(__name__)
CORS(app, resources=r'/*')

upload_file_folder = os.path.join(os.getcwd(), 'model')


def upload():
    file = request.files['files']

    if check_file_type(file.filename):
        file.save(os.path.join(upload_file_folder, file.filename))


def check_file_type(filename):
    file_type = ['pth']
    # 获取文件后缀
    ext = filename.split('.')[1]
    # 判断文件是否是允许上传得类型
    if ext in file_type:
        return True
    else:
        return False


@app.route('/upload_service/', methods=["post", "get"], strict_slashes=False)
def upload_model_file():
    try:
        if request.method == 'POST':
            f = request.files['file']
            if f is not None:
                base_path = sys.path[0]  # 项目的根目录 boot_main.py目录
                if not os.path.exists(os.path.join(base_path, 'model')):
                    os.mkdir(os.path.join(base_path, 'model'))
                upload_path = os.path.join(base_path, 'model',
                                           secure_filename(f.filename))  # 注意：没有的文件夹一定要先创建，不然会提示没有该路径
                f.save(upload_path)
                return json.dumps({"status": 0}, ensure_ascii=False)
            else:
                return json.dumps({"error_msg": "data is None", "status": 1}, ensure_ascii=False)
    except Exception as e:
        traceback.print_exc()
        return json.dumps({"error_msg": "unknown error:" + repr(e), "status": 1}, ensure_ascii=False)


if __name__ == "__main__":
    app.run(host="0.0.0.0", port=2020, debug=True)



# -*- coding:utf-8 -*-
# @author :adolf
__name__ = 'rpa_ocr'
__version__ = '0.1.6'
from rpa_ocr.Identify_English.train_tools import Train
from rpa_ocr.verification_service.verification_main import ocr_pipeline_main
from rpa_ocr.Identify_English.inference import CRNNInference
